@@ -1,11 +1,7 @@
  require("dse1")
  Sys.info()
  version.dse()
- if      (is.R()) data("eg1.DSE.data.diff", package="dse1") else 
- if (is.S()) 
-   {source(paste(DSE.HOME, "/data/eg1.DSE.data.diff.R", sep=""))
-    class(eg1.DSE.data.diff$output) <- class(eg1.DSE.data.diff$input) <- NULL
-    }
+ data("eg1.DSE.data.diff", package="dse1") 
 
  if (!is.TSdata(eg1.DSE.data.diff)) stop("Test data not found. Testing stopped.")
  
@@ -53,7 +49,7 @@ cat("dse1 test 11...\n")
    cat("max. error ", max(error), "\n")
  
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.small < error) 
-     {print.test.value(c(tst), digits=18)
+     {printTestValue(c(tst), digits=18)
       all.ok <- FALSE  
      }
 
@@ -67,7 +63,7 @@ cat("dse1 test 12...\n")
    cat("max. error ", max(error), "\n")
  
    if (any(is.na(error)) || any(is.nan(error)) || fuzz.small < error) 
-     {print.test.value(c(tst), digits=18)
+     {printTestValue(c(tst), digits=18)
       all.ok <- FALSE  
      }
 
