@@ -2,13 +2,8 @@
 
   require("dse2")
  
- if (is.R()) data("egJofF.1dec93.data", package="dse1")else 
- if (is.S()) source(paste(DSE.HOME, "/data/egJofF.1dec93.data.R", sep=""))
- if (is.S()) 
-   {source(paste(DSE.HOME, "/data/egJofF.1dec93.data.R", sep=""))
-    class(egJofF.1dec93.data$output) <- class(egJofF.1dec93.data$input) <- NULL
-    }
-
+ data("egJofF.1dec93.data", package="dse1") 
+ 
   eg4.DSE.data<- egJofF.1dec93.data
   output.data(eg4.DSE.data) <- output.data(eg4.DSE.data, series=c(1,2,6,7))
 
